@@ -1,8 +1,8 @@
-# Copyright (c) 2009 CentralNic Ltd. All rights reserved. This program is
+# Copyright (c) 2011 CentralNic Ltd. All rights reserved. This program is
 # free software; you can redistribute it and/or modify it under the same
 # terms as Perl itself.
 # 
-# $Id: Host.pm,v 1.3 2007/12/03 11:44:52 gavin Exp $
+# $Id: Host.pm,v 1.3 2011/12/03 11:44:52 gavin Exp $
 package Net::EPP::Frame::Command::Check::Host;
 use base qw(Net::EPP::Frame::Command::Check);
 use Net::EPP::Frame::ObjectSpec;
@@ -73,7 +73,7 @@ sub new {
 
 =head1 METHODS
 
-	$frame->addDomain($domain_name);
+	$frame->addHost($host_name);
 
 This adds a hostname to the list of hosts to be checked.
 
@@ -98,7 +98,7 @@ CentralNic Ltd (http://www.centralnic.com/).
 
 =head1 COPYRIGHT
 
-This module is (c) 2007 CentralNic Ltd. This module is free software; you can
+This module is (c) 2011 CentralNic Ltd. This module is free software; you can
 redistribute it and/or modify it under the same terms as Perl itself.
 
 =head1 SEE ALSO
